You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@whimsical.apache.org by cu...@apache.org on 2017/07/03 19:58:15 UTC

[whimsy] branch roster-style updated (aea32bd -> b41c8d7)

This is an automated email from the ASF dual-hosted git repository.

curcuru pushed a change to branch roster-style
in repository https://gitbox.apache.org/repos/asf/whimsy.git.


    from aea32bd  Add whimsy style and minor layout updates
     add c0f3415  map committee to project dn
     add 19febe2  Ignore invalid list headers (avoid NPEs)
     add 035a40c  Doc before code
     add ed8acc3  Use generic list_mod method instead of incubator_mods
     add 8c2014d  add pmc projects to list of committees
     add 33a857c  Docn
     add 48d5682  Put the newly graduated podlings in the new LDAP structure
     add 902fa8c  Update to a useful description Credit: @rbowen
     add c9d9c48  Use common method for parsing list-mods/subs files
     add 64b65ac  Future enhancement
     add 3cd6fb8  Enable the secretary to update the asf-secretary service group
     add aa8e230  convert to use site wide assets
     add 4f07e45  switch to a secure link
     add 393f5b3  mkdir tmp and cleanup .gitignore
     add 9f0f97f  get complete list of PMCs
     add 6c7653e  Show last update time on page
     add 9077f9b  use whimsysvn user for committers who are member or chairs
     add 69d20e5  restore bootstrap-select
     add 9a85e41  grab pmc list from committee-info.txt
     add 32c4367  Allow for cutover to new cron jobs
     add fc47f18  Don't fail if attr not present
     add 3e61c69  Show the LDAP creation date
     add c0b9a43  Show if id is a committer
     add a47366f  pmc chairs don't have write access to subreq
     add e98435e  bit-for-bit copy of mlreq.cgi to start with
     add 24889bb  update mlreq latest dependencies; new LDAP structure
     add 0a29f8f  Add moderation helper to main index
     new ae6b502  Merge branch 'master' into roster-style
     new b41c8d7  More bootstrap styles

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 doap_Whimsy.rdf                                    |    2 +-
 lib/whimsy/asf/ldap.rb                             |   20 +-
 lib/whimsy/asf/mlist.rb                            |  158 +-
 lib/whimsy/asf/person.rb                           |    2 +-
 www/board/subscriptions.cgi                        |    9 +-
 www/committers/assets/bootstrap-select.css         |  300 ++++
 www/committers/assets/bootstrap-select.js          | 1895 ++++++++++++++++++++
 www/committers/subscribe.cgi                       |   17 +-
 www/incubator/moderators.cgi                       |    4 +-
 www/index.html                                     |    1 +
 www/members/subscriptions.cgi                      |   12 +-
 www/officers/mlreq.cgi                             |  520 ++++++
 www/roster/models/committer.rb                     |    7 +
 .../actions/{authgroup.json.rb => service.json.rb} |   25 +-
 www/roster/views/committerSearch.js.rb             |   15 +-
 www/roster/views/group.js.rb                       |   22 +-
 www/roster/views/person.js.rb                      |    7 +
 www/roster/views/pmc/main.js.rb                    |  115 +-
 www/roster/views/podlings.html.rb                  |  149 +-
 www/roster/views/ppmc.html.rb                      |   28 +-
 www/roster/views/ppmcs.html.rb                     |   53 +-
 www/secretary/public-names.cgi                     |    2 +
 www/test/icla/.gitignore                           |    1 -
 www/test/icla/Gemfile                              |   12 +-
 www/test/icla/config.ru                            |    1 +
 www/test/icla/main.rb                              |    2 +-
 www/test/icla/public/assets/bootstrap-min.css      |    5 -
 www/test/icla/public/assets/bootstrap-min.js       |    7 -
 .../icla/public/assets/bootstrap-theme.min.css     |    5 -
 www/test/icla/public/assets/jquery-min.js          |    4 -
 www/test/icla/public/assets/react-min.js           |   15 -
 .../workbench => test/icla}/tmp/.gitignore         |    0
 www/test/icla/views/app.html.rb                    |    2 +-
 33 files changed, 3109 insertions(+), 308 deletions(-)
 create mode 100755 www/committers/assets/bootstrap-select.css
 create mode 100755 www/committers/assets/bootstrap-select.js
 create mode 100755 www/officers/mlreq.cgi
 copy www/roster/views/actions/{authgroup.json.rb => service.json.rb} (62%)
 delete mode 100644 www/test/icla/public/assets/bootstrap-min.css
 delete mode 100644 www/test/icla/public/assets/bootstrap-min.js
 delete mode 100644 www/test/icla/public/assets/bootstrap-theme.min.css
 delete mode 100644 www/test/icla/public/assets/jquery-min.js
 delete mode 100644 www/test/icla/public/assets/react-min.js
 copy www/{secretary/workbench => test/icla}/tmp/.gitignore (100%)

-- 
To stop receiving notification emails like this one, please contact
['"commits@whimsical.apache.org" <co...@whimsical.apache.org>'].

[whimsy] 01/02: Merge branch 'master' into roster-style

Posted by cu...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

curcuru pushed a commit to branch roster-style
in repository https://gitbox.apache.org/repos/asf/whimsy.git

commit ae6b502518f48b32ba0a85184a2bff48f2aa27ff
Merge: aea32bd 0a29f8f
Author: Shane Curcuru <as...@shanecurcuru.org>
AuthorDate: Mon Jul 3 14:53:59 2017 -0400

    Merge branch 'master' into roster-style

 doap_Whimsy.rdf                                    |    2 +-
 lib/whimsy/asf/ldap.rb                             |   20 +-
 lib/whimsy/asf/mlist.rb                            |  158 +-
 lib/whimsy/asf/person.rb                           |    2 +-
 www/board/subscriptions.cgi                        |    9 +-
 www/committers/assets/bootstrap-select.css         |  300 ++++
 www/committers/assets/bootstrap-select.js          | 1895 ++++++++++++++++++++
 www/committers/subscribe.cgi                       |   17 +-
 www/incubator/moderators.cgi                       |    4 +-
 www/index.html                                     |    1 +
 www/members/subscriptions.cgi                      |   12 +-
 www/officers/mlreq.cgi                             |  520 ++++++
 www/roster/models/committer.rb                     |    7 +
 www/roster/views/actions/service.json.rb           |   56 +
 www/roster/views/group.js.rb                       |   22 +-
 www/roster/views/person.js.rb                      |    7 +
 www/secretary/public-names.cgi                     |    2 +
 www/test/icla/.gitignore                           |    1 -
 www/test/icla/Gemfile                              |   12 +-
 www/test/icla/config.ru                            |    1 +
 www/test/icla/main.rb                              |    2 +-
 www/test/icla/public/assets/bootstrap-min.css      |    5 -
 www/test/icla/public/assets/bootstrap-min.js       |    7 -
 .../icla/public/assets/bootstrap-theme.min.css     |    5 -
 www/test/icla/public/assets/jquery-min.js          |    4 -
 www/test/icla/public/assets/react-min.js           |   15 -
 www/test/icla/tmp/.gitignore                       |    1 +
 www/test/icla/views/app.html.rb                    |    2 +-
 28 files changed, 2964 insertions(+), 125 deletions(-)

-- 
To stop receiving notification emails like this one, please contact
"commits@whimsical.apache.org" <co...@whimsical.apache.org>.

[whimsy] 02/02: More bootstrap styles

Posted by cu...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

curcuru pushed a commit to branch roster-style
in repository https://gitbox.apache.org/repos/asf/whimsy.git

commit b41c8d7c0a67db04b418b5ba059167b7ae9be8b1
Author: Shane Curcuru <as...@shanecurcuru.org>
AuthorDate: Mon Jul 3 15:58:09 2017 -0400

    More bootstrap styles
    
    Note: not complete, but wrapping all pages and updating a few obvious
    control boxes
---
 www/roster/views/committerSearch.js.rb |  15 +++-
 www/roster/views/pmc/main.js.rb        | 115 ++++++++++++-------------
 www/roster/views/podlings.html.rb      | 149 +++++++++++++++++----------------
 www/roster/views/ppmc.html.rb          |  28 ++++---
 www/roster/views/ppmcs.html.rb         |  53 +++++++-----
 5 files changed, 193 insertions(+), 167 deletions(-)

diff --git a/www/roster/views/committerSearch.js.rb b/www/roster/views/committerSearch.js.rb
index 03ebe8f..7974215 100644
--- a/www/roster/views/committerSearch.js.rb
+++ b/www/roster/views/committerSearch.js.rb
@@ -56,9 +56,18 @@ class CommitterSearch < React
   end
 
   def render
-    _label 'Search:', for: 'search-text'
-    _input.search_text! autofocus: true, value: @search, onChange: self.change
-
+    _div.form_group do
+      _label.control_label.col_sm_3 'Search for', for:  'search-text'
+      _div.col_sm_9 do
+        _div.input_group do
+          _input.form_control.search_text! autofocus: true, value: @search, onChange: self.change
+          _span.input_group_addon do
+            _span.glyphicon.glyphicon_user aria_label: "Committer ID or name"
+          end
+        end
+      end
+    end
+    
     if @search.length
       if not @ready
         _p 'loading...'
diff --git a/www/roster/views/podlings.html.rb b/www/roster/views/podlings.html.rb
index 88b3cd8..dec2eb8 100644
--- a/www/roster/views/podlings.html.rb
+++ b/www/roster/views/podlings.html.rb
@@ -3,93 +3,96 @@
 #
 
 _html do
-  _title 'ASF Podling list'
   _link rel: 'stylesheet', href: 'stylesheets/app.css'
   _style %{
     p {margin-top: 0.5em}
   }
-
-  _banner breadcrumbs: {
-    roster: '.',
-    podlings: 'podlings'
-  }
-
-  # ********************************************************************
-  # *                             Summary                              *
-  # ********************************************************************
-
-  _h1_ 'Summary'
- 
-  _table.counts do
-    @podlings.group_by {|podling| podling.status}.sort.each do |status, list|
-      _tr do
-        _td list.count
-        _td do
-          _a status, href: "http://incubator.apache.org/projects/##{status}"
+  _body? do
+    _whimsy_body(
+      title: 'ASF Podling list',
+      breadcrumbs: {
+        roster: '.',
+        podlings: 'podlings'
+      }
+    ) do
+      
+      # ********************************************************************
+      # *                             Summary                              *
+      # ********************************************************************
+      _whimsy_panel_table(
+        title: 'Podling Summary',
+        helpblock: -> {
+          _ 'Podling data is derived from:'
+          _a 'podlings.xml', href: 'https://svn.apache.org/repos/asf/incubator/public/trunk/content/podlings.xml'
+        }
+      ) do
+        _table.counts do
+          @podlings.group_by {|podling| podling.status}.sort.each do |status, list|
+            _tr do
+              _td list.count
+              _td do
+                _a status, href: "http://incubator.apache.org/projects/##{status}"
+              end
+            end
+          end
         end
       end
-    end
-  end
-
-  _p do
-    _ 'Data is derived from:'
-    _a 'podlings.xml', href: 'https://svn.apache.org/repos/asf/incubator/public/trunk/content/podlings.xml'
-  end
-
-  # ********************************************************************
-  # *                          Complete list                           *
-  # ********************************************************************
 
-  color = {
-    'current'   => 'bg-info',
-    'graduated' => 'bg-success',
-    'retired'   => 'bg-warning',
-    'attic'     => 'bg-danger'
-   }
+      # ********************************************************************
+      # *                          Complete list                           *
+      # ********************************************************************
+      color = {
+        'current'   => 'bg-info',
+        'graduated' => 'bg-success',
+        'retired'   => 'bg-warning',
+        'attic'     => 'bg-danger'
+       }
 
-  _h1_ 'Podlings'
-  _h5_ do
-    _ 'Click on a column heading to change the sort order ('
-    color.each do |state, clazz|
-      _span state, class: clazz
-      _ " "
-    end
-    _ ")"
-  end
-    
-  _table.table.table_hover do
-    _thead do
-      _tr do
-        _th.sorting_asc 'Name', data_sort: 'string-ins'
-        _th 'Status', data_sort: 'string'
-        _th 'Description', data_sort: 'string'
+      _h2_ 'Podlings'
+      _h5_ do
+        _ 'Click on a column heading to change the sort order ('
+        color.each do |state, clazz|
+          _span state, class: clazz
+          _ " "
+        end
+        _ ")"
       end
-    end
+        
+      _table.table.table_hover do
+        _thead do
+          _tr do
+            _th.sorting_asc 'Name', data_sort: 'string-ins'
+            _th 'Status', data_sort: 'string'
+            _th 'Description', data_sort: 'string'
+          end
+        end
 
-    _tbody do
-      @podlings.sort_by {|podling| podling.name.downcase}.each do |podling|
-        status = (@attic.include?(podling.name) ? 'attic' : podling.status)
+        _tbody do
+          @podlings.sort_by {|podling| podling.name.downcase}.each do |podling|
+            status = (@attic.include?(podling.name) ? 'attic' : podling.status)
 
-        _tr_ class: color[status] do
-          _td do
-            _a podling.display_name, href:
-              "http://incubator.apache.org/projects/#{podling.name}.html"
-          end
+            _tr_ class: color[status] do
+              _td do
+                _a podling.display_name, href:
+                  "http://incubator.apache.org/projects/#{podling.name}.html"
+              end
 
-          if @committees.include? podling.name
-            _td data_sort_value: "#{podling.status} - pmc" do
-              _a podling.status, href: "committee/#{podling.name}"
-            end
-          elsif @attic.include? podling.name
-            _td data_sort_value: "#{podling.status} - attic" do
-              _a podling.status, href:
-                "http://attic.apache.org/projects/#{podling.name}.html"
+              if @committees.include? podling.name
+                _td data_sort_value: "#{podling.status} - pmc" do
+                  _a podling.status, href: "committee/#{podling.name}"
+                end
+              elsif @attic.include? podling.name
+                _td data_sort_value: "#{podling.status} - attic" do
+                  _a podling.status, href:
+                    "http://attic.apache.org/projects/#{podling.name}.html"
+                end
+              else
+                _td podling.status
+              end
+
+              _td podling.description
             end
-          else
-            _td podling.status
           end
-
-          _td podling.description
         end
       end
     end
diff --git a/www/roster/views/ppmc.html.rb b/www/roster/views/ppmc.html.rb
index cdaef5d..8aafe60 100644
--- a/www/roster/views/ppmc.html.rb
+++ b/www/roster/views/ppmc.html.rb
@@ -4,19 +4,21 @@
 
 _html do
   _base href: '..'
-  _title @ppmc[:display_name]
   _link rel: 'stylesheet', href: 'stylesheets/app.css'
-
-  _banner breadcrumbs: {
-    roster: '.',
-    ppmc: 'ppmc/',
-    @ppmc[:id] => "ppmc/#{@ppmc[:id]}"
-  }
-
-  _div_.main!
-
-  _script src: 'app.js'
-  _.render '#main' do
-    _PPMC ppmc: @ppmc, auth: @auth
+  _body? do
+    _whimsy_body(
+      title: @ppmc[:display_name],
+      breadcrumbs: {
+        roster: '.',
+        ppmc: 'ppmc/',
+        @ppmc[:id] => "ppmc/#{@ppmc[:id]}"
+      }
+    ) do
+      _div_.main!
+      _script src: 'app.js'
+      _.render '#main' do
+        _PPMC ppmc: @ppmc, auth: @auth
+      end
+    end
   end
 end
diff --git a/www/roster/views/ppmcs.html.rb b/www/roster/views/ppmcs.html.rb
index 059f76d..477c1cc 100644
--- a/www/roster/views/ppmcs.html.rb
+++ b/www/roster/views/ppmcs.html.rb
@@ -4,39 +4,48 @@
 
 _html do
   _base href: '..'
-  _title 'ASF Podling PMC Roster'
+  _title 
   _link rel: 'stylesheet', href: 'stylesheets/app.css'
 
   _banner breadcrumbs: {
     roster: '.',
     ppmc: 'ppmc/'
   }
+  _body? do
+    _whimsy_body(
+      title: 'ASF Podling PMC Roster',
+      breadcrumbs: {
+        roster: '.',
+        ppmc: 'ppmc/'
+      }
+    ) do
+      _p 'A listing of all Podling Project Management Committees (PPMCs) from the Apache Incubator.'
 
-  _h1 'Podling Project Management Committees (PPMCs)'
-
-  _table.table.table_hover do
-    _thead do
-      _tr do
-        _th 'Name'
-        _th 'Established'
-        _th 'Description'
-      end
-    end
-
-    project_names = @projects.map {|project| project.name}
-    @ppmcs.sort_by {|ppmc| ppmc.display_name.downcase}.each do |ppmc|
-      _tr_ do
-        _td do
-          if project_names.include? ppmc.name
-            _a ppmc.display_name, href: "ppmc/#{ppmc.name}"
-          else
-            _a.label_danger ppmc.display_name, href: "ppmc/#{ppmc.name}"
+      _table.table.table_hover do
+        _thead do
+          _tr do
+            _th 'Name'
+            _th 'Established'
+            _th 'Description'
           end
         end
 
-        _td ppmc.startdate
+        project_names = @projects.map {|project| project.name}
+        @ppmcs.sort_by {|ppmc| ppmc.display_name.downcase}.each do |ppmc|
+          _tr_ do
+            _td do
+              if project_names.include? ppmc.name
+                _a ppmc.display_name, href: "ppmc/#{ppmc.name}"
+              else
+                _a.label_danger ppmc.display_name, href: "ppmc/#{ppmc.name}"
+              end
+            end
 
-        _td ppmc.description
+            _td ppmc.startdate
+
+            _td ppmc.description
+          end
+        end
       end
     end
   end

diff --git a/www/roster/views/pmc/main.js.rb b/www/roster/views/pmc/main.js.rb
index d7c0992..1480b21 100644
--- a/www/roster/views/pmc/main.js.rb
+++ b/www/roster/views/pmc/main.js.rb
@@ -1,4 +1,4 @@
-#
+ #
 # Show a PMC
 #
 
@@ -15,15 +15,20 @@ class PMC < React
       auth = (@@auth.id == @committee.chair or @@auth.secretary or @@auth.root)
     end
 
-    # add jump links to main sections of page
-    _div.breadcrumbs do
-      _a 'PMC', :href => "committee/#{@committee.id}#pmc"
-      _span " \u00BB "
-      _a 'Mail Moderators', :href => "committee/#{@committee.id}#mail"
-      _span " \u00BB "
-      _a 'Reporting Schedule', :href => "committee/#{@committee.id}#reporting"
-      _span " \u00BB "
-      _a 'Links', :href => "committee/#{@committee.id}#links"
+    # add jump links to main sections of page using Bootstrap nav element
+    _ul.nav.nav_pills do
+      _li role: "presentation" do
+        _a 'PMC', :href => "committee/#{@committee.id}#pmc"
+      end
+      _li role: "presentation" do
+        _a 'Mail Moderators', :href => "committee/#{@committee.id}#mail"
+      end
+      _li role: "presentation" do
+        _a 'Reporting Schedule', :href => "committee/#{@committee.id}#reporting"
+      end
+      _li role: "presentation" do
+        _a 'Links', :href => "committee/#{@committee.id}#links"
+      end
     end
 
     # header
@@ -103,55 +108,53 @@ class PMC < React
       end
     end
 
-    # reporting schedule
-    _h2.reporting! 'Reporting Schedule'
-    _ul do
-      _li @committee.report
-
-      if @committee.schedule and @committee.schedule != @committee.report
-        _li @committee.schedule 
-      end
 
-      _li do
-        _a 'Prior reports', href: 'https://whimsy.apache.org/board/minutes/' +
-          @committee.display_name.gsub(/\s+/, '_')
-      end
-
-      if @committee.ldap[@@auth.id] or @@auth.member
-        _li do
-          _a 'Apache Committee Report Helper',
-            href: "https://reporter.apache.org/?#{@committee.id}"
+    # reporting schedule and links
+    _div.row do
+      _div.col_md_6 do
+        _h3.reporting! 'Reporting Schedule'
+        _ul do
+          _li @committee.report
+          if @committee.schedule and @committee.schedule != @committee.report
+            _li @committee.schedule 
+          end
+          _li do
+            _a 'Prior reports', href: 'https://whimsy.apache.org/board/minutes/' +
+              @committee.display_name.gsub(/\s+/, '_')
+          end
+          if @committee.ldap[@@auth.id] or @@auth.member
+            _li do
+              _a 'Apache Committee Report Helper',
+                href: "https://reporter.apache.org/?#{@committee.id}"
+            end
+          end
         end
       end
-    end
-
-    _h2.links! 'Links'
-    _ul do
-      _li {_a 'Site check', href: "../site/project/#{@committee.id}"}
-
-      info = @committee.project_info
-
-      if info
-        if info.doap
-          _li {_a 'DOAP', href: info.doap}
-        end
-
-        if info['download-page']
-          _li {_a 'Download Page', href: info['download-page']}
-        end
-
-        if info['bug-database']
-          _li {_a 'Bug Database', href: info['bug-database']}
-        end
-
-        if info.repository and not info.repository.empty?
-          if info.repository.length == 1
-            _li {_a 'Repository', href: info.repository.first}
-          else
-            _li do
-              _span 'Repositories:'
-              _ul info.repository do |repository|
-                _li {_a repository, href: repository}
+      _div.col_md_6 do
+        _h3.links! 'Links'
+        _ul do
+          _li {_a 'Site check', href: "../site/project/#{@committee.id}"}
+          info = @committee.project_info
+          if info
+            if info.doap
+              _li {_a 'DOAP', href: info.doap}
+            end
+            if info['download-page']
+              _li {_a 'Download Page', href: info['download-page']}
+            end
+            if info['bug-database']
+              _li {_a 'Bug Database', href: info['bug-database']}
+            end
+            if info.repository and not info.repository.empty?
+              if info.repository.length == 1
+                _li {_a 'Repository', href: info.repository.first}
+              else
+                _li do
+                  _span 'Repositories:'
+                  _ul info.repository do |repository|
+                    _li {_a repository, href: repository}
+                  end
+                end
               end
             end
           end
-- 
To stop receiving notification emails like this one, please contact
"commits@whimsical.apache.org" <co...@whimsical.apache.org>.